@@ -1,6 +1,11 @@
-from typing import Callable
+from enum import IntEnum
+from typing import Callable, Optional, Tuple
 
 import numpy as np
+import torch
+
+from l5kit.planning import utils
+
 
 metric_signature = Callable[[np.ndarray, np.ndarray, np.ndarray, np.ndarray], np.ndarray]
 
@@ -36,7 +41,7 @@ def _assert_shapes(ground_truth: np.ndarray, pred: np.ndarray, confidences: np.n
 
 
 def neg_multi_log_likelihood(
-    ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray
+        ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray
 ) -> np.ndarray:
     """
     Compute a negative log-likelihood for the multi-modal scenario.
@@ -94,7 +99,7 @@ def rmse(ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, av
 
 
 def prob_true_mode(
-    ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray
+        ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray
 ) -> np.ndarray:
     """
     Return the probability of the true mode
@@ -127,7 +132,7 @@ def prob_true_mode(
 
 
 def time_displace(
-    ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray
+        ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray
 ) -> np.ndarray:
     """
     Return the displacement at timesteps T
@@ -153,7 +158,7 @@ def time_displace(
 
 
 def _average_displacement_error(
-    ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray, mode: str
+        ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray, mode: str
 ) -> np.ndarray:
     """
     Returns the average displacement error (ADE), which is the average displacement over all timesteps.
@@ -191,7 +196,7 @@ def _average_displacement_error(
 
 
 def average_displacement_error_oracle(
-    ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray,
+        ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray,
 ) -> np.ndarray:
     """
     Calls _average_displacement_error() to get the oracle average displacement error.
@@ -210,7 +215,7 @@ def average_displacement_error_oracle(
 
 
 def average_displacement_error_mean(
-    ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray,
+        ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray,
 ) -> np.ndarray:
     """
     Calls _average_displacement_error() to get the mean average displacement error.
@@ -229,7 +234,7 @@ def average_displacement_error_mean(
 
 
 def _final_displacement_error(
-    ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray, mode: str
+        ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray, mode: str
 ) -> np.ndarray:
     """
     Returns the final displacement error (FDE), which is the displacement calculated at the last timestep.
@@ -267,7 +272,7 @@ def _final_displacement_error(
 
 
 def final_displacement_error_oracle(
-    ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray,
+        ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray,
 ) -> np.ndarray:
     """
     Calls _final_displacement_error() to get the oracle average displacement error.
@@ -286,7 +291,7 @@ def final_displacement_error_oracle(
 
 
 def final_displacement_error_mean(
-    ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray,
+        ground_truth: np.ndarray, pred: np.ndarray, confidences: np.ndarray, avails: np.ndarray,
 ) -> np.ndarray:
     """
     Calls _final_displacement_error() to get the mean average displacement error.
@@ -302,3 +307,80 @@ def final_displacement_error_mean(
     """
 
     return _final_displacement_error(ground_truth, pred, confidences, avails, "mean")
+
+
+class CollisionType(IntEnum):
+    """This enum defines the three types of collisions: front, rear and side."""
+    FRONT = 0
+    REAR = 1
+    SIDE = 2
+
+
+def detect_collision(pred_centroid: np.ndarray, pred_yaw: np.ndarray,
+                     pred_extent: np.ndarray, target_agents: np.ndarray) -> Optional[Tuple[CollisionType, str]]:
+    """
+    Computes whether a collision occured between ego and any another agent.
+    Also computes the type of collision: rear, front, or side.
+    For this, we compute the intersection of ego's four sides with a target
+    agent and measure the length of this intersection. A collision
+    is classified into a class, if the corresponding length is maximal,
+    i.e. a front collision exhibits the longest intersection with
+    egos front edge.
+
+    .. note:: please note that this funciton will stop upon finding the first
+              colision, so it won't return all collisions but only the first
+              one found.
+
+    :param pred_centroid: predicted centroid
+    :param pred_yaw: predicted yaw
+    :param pred_extent: predicted extent
+    :param target_agents: target agents
+    :return: None if not collision was found, and a tuple with the
+             collision type and the agent track_id
+    """
+    ego_bbox = utils._get_bounding_box(centroid=pred_centroid, yaw=pred_yaw, extent=pred_extent)
+    within_range_mask = utils.within_range(pred_centroid, pred_extent,
+                                           target_agents["centroid"], target_agents["extent"])
+    for agent in target_agents[within_range_mask]:
+        agent_bbox = utils._get_bounding_box(agent["centroid"], agent["yaw"], agent["extent"])
+
+        if ego_bbox.intersects(agent_bbox):
+            front_side, rear_side, left_side, right_side = utils._get_sides(ego_bbox)
+
+            intersection_length_per_side = np.asarray(
+                [
+                    agent_bbox.intersection(front_side).length,
+                    agent_bbox.intersection(rear_side).length,
+                    agent_bbox.intersection(left_side).length,
+                    agent_bbox.intersection(right_side).length,
+                ]
+            )
+            argmax_side = np.argmax(intersection_length_per_side)
+
+            # Remap here is needed because there are two sides that are
+            # mapped to the same collision type CollisionType.SIDE
+            max_collision_types = max(CollisionType).value
+            remap_argmax = min(argmax_side, max_collision_types)
+            collision_type = CollisionType(remap_argmax)
+            return collision_type, agent["track_id"]
+    return None
+
+
+def distance_to_reference_trajectory(pred_centroid: torch.Tensor, ref_traj: torch.Tensor) -> torch.Tensor:
+    """ Computes the distance from the predicted centroid to the closest waypoint in the reference trajectory.
+
+    :param pred_centroid: predicted centroid tensor, size: [batch_size, 2]
+    :type pred_centroid: torch.Tensor, float
+    :param ref_traj: reference trajectory tensor, size: [batch_size, num_timestamps, 2]
+    :type ref_traj: torch.Tensor, float
+    :return: closest distance between the predicted centroid and the reference trajectory, size: [batch_size,]
+    :rtype: torch.Tensor, float
+    """
+    # [batch_size, 2]
+    assert pred_centroid.dim() == 2
+    # [batch_size, num_timestamps, 2]
+    assert ref_traj.dim() == 3
+
+    # [batch_size,]
+    euclidean_distance = torch.linalg.norm(pred_centroid.unsqueeze(1) - ref_traj, ord=2, dim=-1)
+    return torch.amin(euclidean_distance, dim=1)
